@@ -9,12 +9,12 @@
 //! the input function inside the node.
 
 #![allow(clippy::unnecessary_wraps)]
-#![deny(
+#![deny(unsafe_code)]
+#![warn(
     missing_docs,
     dead_code,
     trivial_casts,
     trivial_numeric_casts,
-    unsafe_code,
     unused_import_braces,
     unused_qualifications
 )]
